@@ -111,13 +111,13 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
 
         self.show()
 
-        # The magical constants of 120 here are derived from margins set
+        # The magical constants of 60 here are derived from margins set
         # in the .ui file
-        req_width = self.scrollAreaWidgetContents_2.sizeHint().width() + 120
-        avail_width = self.app.desktop().availableGeometry().width() * 0.9
+        req_width = self.scrollAreaWidgetContents_2.sizeHint().width() + 60
+        avail_width = self.app.desktop().availableGeometry().width() * 0.95
 
-        req_height = self.scrollAreaWidgetContents_2.sizeHint().height() + 120
-        avail_height = self.app.desktop().availableGeometry().height() * 0.9
+        req_height = self.scrollAreaWidgetContents_2.sizeHint().height() + 60
+        avail_height = self.app.desktop().availableGeometry().height() * 0.95
 
         self.resize(min(req_width, avail_width), min(req_height, avail_height))
 
@@ -212,7 +212,8 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
         # default netvm
         if utils.did_widget_selection_change(self.default_netvm_combo):
             new_default_netvm = self.default_netvm_combo.currentData()
-            if new_default_netvm.property_is_default('netvm'):
+            if new_default_netvm and \
+                    new_default_netvm.property_is_default('netvm'):
                 self.errors.append(
                     "Cannot set {} as the default net qube. Reason: {}'s net"
                     " qube is already set to 'default', and a qube cannot be "
